import { nameof } from 'ts-simple-nameof';
import { TypedEvent } from './TypedEvent';
import { LoggerService } from './Services/Logging/LoggerService';
var DependencyContainer = (function () {
    function DependencyContainer() {
        this._services = {};
        this._serviceRegistrationEvent = new TypedEvent();
    }
    Object.defineProperty(DependencyContainer, "Instance", {
        get: function () {
            if (!DependencyContainer._instance)
                DependencyContainer._instance = new DependencyContainer();
            this.Log = new LoggerService();
            DependencyContainer._instance.RegisterService(this.Log);
            this.IsInitialized = true;
            return DependencyContainer._instance;
        },
        enumerable: false,
        configurable: true
    });
    DependencyContainer.prototype.RegisterService = function (service) {
        var _a;
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, "[DI] Registering new service: ".concat(service.GetServiceName()));
        this._services[service.GetServiceName()] = service;
    };
    DependencyContainer.prototype.GetService = function (classType) {
        var _a;
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, "[DI] Getting service for GetService<".concat(nameof(classType), ">"));
        return this._services[nameof(classType)];
    };
    DependencyContainer.prototype.GetServiceAsync = function (classType, token) {
        var _this = this;
        var _a;
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, "[DI] Waiting for service availability for GetServiceAsync<".concat(nameof(classType), ">"));
        return new Promise(function (resolve, reject) {
            var sub = function (service) {
                var _a;
                if ((service === null || service === void 0 ? void 0 : service.GetServiceName()) === nameof(classType)) {
                    (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, "[DI] Got service for GetServiceAsync<".concat(nameof(classType), ">"));
                    _this._serviceRegistrationEvent.Unsubscribe(sub);
                    resolve(service);
                }
            };
            var onCancel = function () {
                var _a;
                _this._serviceRegistrationEvent.Unsubscribe(sub);
                token === null || token === void 0 ? void 0 : token.CancellationEvent.Unsubscribe(onCancel);
                (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, "[DI] Cancelled service retrieval for GetServiceAsync<".concat(nameof(classType), ">"));
                reject(new Error("Operation cancelled!"));
            };
            token === null || token === void 0 ? void 0 : token.CancellationEvent.Subscribe(onCancel);
            _this._serviceRegistrationEvent.Subscribe(sub);
        });
    };
    DependencyContainer.prototype.GetServiceWithTimeoutAsync = function (classType, timeout) {
        var _this = this;
        var _a;
        (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, "[DI] Waiting for service availability for GetServiceWithTimeoutAsync<".concat(nameof(classType), ">"));
        return new Promise(function (resolve, reject) {
            var timeoutId = 0;
            var sub = function (service) {
                var _a;
                if ((service === null || service === void 0 ? void 0 : service.GetClassName()) === nameof(classType)) {
                    (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Debug(DependencyContainer, "[DI] Got service for GetServiceWithTimeoutAsync<".concat(nameof(classType), ">"));
                    window.clearTimeout(timeoutId);
                    _this._serviceRegistrationEvent.Unsubscribe(sub);
                    resolve(service);
                }
            };
            var onTimeout = function () {
                var _a;
                window.clearTimeout(timeoutId);
                _this._serviceRegistrationEvent.Unsubscribe(sub);
                (_a = DependencyContainer.Log) === null || _a === void 0 ? void 0 : _a.Error(DependencyContainer, "[DI] Failed to get service in time for GetServiceWithTimeoutAsync<".concat(nameof(classType), ">"));
                reject(new Error("Operation cancelled!"));
            };
            timeoutId = window.setTimeout(onTimeout, timeout);
            _this._serviceRegistrationEvent.Subscribe(sub);
        });
    };
    DependencyContainer.IsInitialized = false;
    return DependencyContainer;
}());
export { DependencyContainer };
//# sourceMappingURL=DependencyContainer.js.map