import { nameof } from "ts-simple-nameof";
import { LogLevel } from "./ILoggerService";
var LoggerService = (function () {
    function LoggerService() {
        this._logLevel = LogLevel.Debug;
    }
    Object.defineProperty(LoggerService.prototype, "LogLevel", {
        get: function () {
            return this._logLevel;
        },
        set: function (level) {
            this._logLevel = level;
        },
        enumerable: false,
        configurable: true
    });
    LoggerService.prototype.GetServiceName = function () {
        return nameof(LoggerService);
    };
    LoggerService.prototype.GetTimeStamp = function () {
        var date = new Date();
        return "".concat(date.getHours(), ":").concat(date.getMinutes(), ":").concat(date.getSeconds(), ".").concat(date.getMilliseconds(), " | ");
    };
    LoggerService.prototype.Warning = function (contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Warning:
            case LogLevel.Info:
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            console.info("".concat(this.GetTimeStamp(), "[WARN] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.warn("".concat(this.GetTimeStamp(), "[WARN] [").concat(nameof(contextClassType), "] ").concat(message));
        else
            console.warn("".concat(this.GetTimeStamp(), "[WARN] ").concat(message));
    };
    LoggerService.prototype.Error = function (contextClassType, message) {
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            console.info("".concat(this.GetTimeStamp(), "[ERROR] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.error("".concat(this.GetTimeStamp(), "[ERROR] [").concat(nameof(contextClassType), "] ").concat(message));
        else
            console.error("".concat(this.GetTimeStamp(), "[ERROR] ").concat(message));
    };
    LoggerService.prototype.Info = function (contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Info:
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            console.info("".concat(this.GetTimeStamp(), "[INFO] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.info("".concat(this.GetTimeStamp(), "[INFO] [").concat(nameof(contextClassType), "] ").concat(message));
        else
            console.info("".concat(this.GetTimeStamp(), "[INFO] ").concat(message));
    };
    LoggerService.prototype.Debug = function (contextClassType, message) {
        switch (this._logLevel) {
            case LogLevel.Debug:
                break;
            default:
                return;
        }
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            console.info("".concat(this.GetTimeStamp(), "[DEBUG] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.info("".concat(this.GetTimeStamp(), "[DEBUG] [").concat(nameof(contextClassType), "] ").concat(message));
        else
            console.info("".concat(this.GetTimeStamp(), "[DEBUG] ").concat(message));
    };
    LoggerService.prototype.Log = function (contextClassType, message) {
        if (contextClassType != null && (typeof contextClassType === 'string' || contextClassType instanceof String))
            console.info("".concat(this.GetTimeStamp(), "[LOG] [").concat(contextClassType, "] ").concat(message));
        else if (contextClassType != null && contextClassType instanceof Object)
            console.log("".concat(this.GetTimeStamp(), "[LOG] [").concat(nameof(contextClassType), "] ").concat(message));
        else
            console.log("".concat(this.GetTimeStamp(), "[LOG] ").concat(message));
    };
    return LoggerService;
}());
export { LoggerService };
//# sourceMappingURL=LoggerService.js.map